@@ -6,7 +6,6 @@ __copyright__ = 'Copyright © Md Jahidul Hamid <https://github.com/neurobin/>'
 __license__ = '[BSD](http://www.opensource.org/licenses/bsd-license.php)'
 __version__ = '0.1.0'
 
-import collections
 import re
 import asyncio
 import nest_asyncio  # type: ignore
@@ -15,12 +14,11 @@ import logging
 
 import asyncpg # type: ignore
 from asyncpg import Record, Connection # type: ignore
-from typing import Optional, Dict, List, Tuple, TypeVar, Union, Any
+from typing import Dict, List, Tuple, Union, Any
 
 from morm import exceptions
 from morm.model import ModelType, Model, ModelBase, _FieldNames
 from morm.q import Q
-from morm.types import Void
 
 LOGGER_NAME = 'morm.db-'
 log = logging.getLogger(LOGGER_NAME)
@@ -78,7 +76,7 @@ class Pool(object):
         loop ([type], optional): Asyncio even loop instance. Defaults to None.
         connection_class ([type], optional): The class to use for connections.  Must be a subclass of `asyncpg.connection.Connection`. Defaults to asyncpg.connection.Connection.
     """
-    def __init__(self, dsn: str = None,
+    def __init__(self, dsn: str|None = None,
                  min_size: int = 10,
                  max_size: int = 100,
                  max_queries: int = 50000,
@@ -175,8 +173,9 @@ class DB(object):
         return self._pool.pool
 
     async def fetch(self, query: str, *args,
-                    timeout: float = None,
-                    model_class: ModelType=None
+                    timeout: float|None = None,
+                    model_class: ModelType|None = None,
+                    **kwargs
                     ) -> Union[List[ModelBase], List[Record]]:
         """Make a query and get the results.
 
@@ -187,6 +186,10 @@ class DB(object):
             args (*list or *tuple): Query arguments.
             timeout (float, optional): Timeout value. Defaults to None.
             model_class (Model, optional): Defaults to None.
+            kwargs (**dict) : Other arguments that are not supported by
+                this method but may be supported by other methods.
+                This is to allow passing arguments to other methods
+                without changing the code.
 
         Returns:
             List[Model] or List[Record] : List of model instances if model_class is given, otherwise list of Record instances.
@@ -203,8 +206,9 @@ class DB(object):
             return new_records
 
     async def fetchrow(self, query: str, *args,
-                        timeout: float = None,
-                        model_class: ModelType=None
+                        timeout: float|None = None,
+                        model_class: ModelType|None = None,
+                        **kwargs
                         ) -> Union[ModelBase, Record]:
         """Make a query and get the first row.
 
@@ -215,6 +219,10 @@ class DB(object):
             args (*list or *tuple): Query arguments.
             timeout (float, optional): Timeout value. Defaults to None.
             model_class (Model, optional): Defaults to None.
+            kwargs (**dict) : Other arguments that are not supported by
+                this method but may be supported by other methods.
+                This is to allow passing arguments to other methods
+                without changing the code.
 
         Returns:
             Record or model_clas object or None if no rows were selected.
@@ -231,7 +239,8 @@ class DB(object):
 
     async def fetchval(self, query: str, *args,
                         column: int = 0,
-                        timeout: float = None
+                        timeout: float|None = None,
+                        **kwargs
                         ) -> Any:
         """Run a query and return a column value in the first row.
 
@@ -240,6 +249,10 @@ class DB(object):
             args (*list or *tuple): Query arguments.
             column (int, optional): Column index. Defaults to 0.
             timeout (float, optional): Timeout. Defaults to None.
+            kwargs (**dict) : Other arguments that are not supported by
+                this method but may be supported by other methods.
+                This is to allow passing arguments to other methods
+                without changing the code.
 
         Returns:
             Any: Coulmn (indentified by index) value of first row.
@@ -248,7 +261,8 @@ class DB(object):
         return await pool.fetchval(query, *args, column=column, timeout=timeout)
 
     async def execute(self, query: str, *args,
-                        timeout: float = None
+                        timeout: float|None = None,
+                        **kwargs
                         ) -> str:
         """Execute a query.
 
@@ -256,6 +270,10 @@ class DB(object):
             query (str): Query to run.
             args (*list or *tuple): Query arguments.
             timeout (float, optional): Timeout. Defaults to None.
+            kwargs (**dict) : Other arguments that are not supported by
+                this method but may be supported by other methods.
+                This is to allow passing arguments to other methods
+                without changing the code.
 
         Returns:
             str: Status of the last SQL command
@@ -274,7 +292,7 @@ class DB(object):
             (str, list): query, args
         """
         data = mob.Meta._fields_
-        new_data_gen = mob.__class__._get_FieldValue_data_valid_(data, up=True)
+        new_data_gen = mob.__class__._get_FieldValue_data_valid_(data, up=True, validate_all=True)
         columns = []
         values = []
         markers = []
@@ -345,7 +363,7 @@ class DB(object):
         query = f'DELETE FROM "{mob.__class__._get_db_table_()}" WHERE "{mob.__class__._get_pk_()}"=$1'
         return query, [pkval]
 
-    async def delete(self, mob: ModelBase, timeout: float = None) -> str:
+    async def delete(self, mob: ModelBase, timeout: float|None = None) -> str:
         """Delete the model object data from database.
 
         Args:
@@ -361,7 +379,7 @@ class DB(object):
         await mob._post_delete_(self)
         return res
 
-    async def insert(self, mob: ModelBase, timeout: float = None) -> Any:
+    async def insert(self, mob: ModelBase, timeout: float|None = None) -> Any:
         """Insert the current data state of mob into db.
 
         Args:
@@ -379,7 +397,7 @@ class DB(object):
         await mob._post_insert_(self)
         return pkval
 
-    async def update(self, mob: ModelBase, timeout: float = None) -> str:
+    async def update(self, mob: ModelBase, timeout: float|None = None) -> str:
         """Update the current changed data of mob onto db
 
         Args:
@@ -404,7 +422,7 @@ class DB(object):
         return res
 
 
-    async def save(self, mob: ModelBase, timeout: float = None) -> Union[str, Any]:
+    async def save(self, mob: ModelBase, timeout: float|None = None) -> Union[str, Any]:
         """Insert if not exists and update if exists.
 
         update is tried first, if fails (if pk does not exist), insert
@@ -426,7 +444,7 @@ class DB(object):
         await mob._post_save_(self)
         return res
 
-    def q(self, model: ModelType = None) -> 'ModelQuery':
+    def q(self, model: ModelType|None = None) -> 'ModelQuery':
         """Return a ModelQuery for model
 
         If `None` is passed, it will give a `ModelQuery` without setting
@@ -444,7 +462,7 @@ class DB(object):
         return self(model)
 
 
-    def __call__(self, model: ModelType = None) -> 'ModelQuery':
+    def __call__(self, model: ModelType|None = None) -> 'ModelQuery':
         """Return a ModelQuery for model
 
         If `None` is passed, it will give a `ModelQuery` without setting
@@ -520,7 +538,7 @@ class ModelQuery():
         db (DB): DB object
         model_class (ModelType): model
     """
-    def __init__(self, db: DB, model_class: ModelType = None):
+    def __init__(self, db: DB, model_class: ModelType|None = None):
         self.reset()
         self.db = db
         self.model = model_class # can be None
@@ -906,7 +924,7 @@ class ModelQuery():
         query = f'{self.start_query_str} {query} {self.end_query_str}'
         return query, self._args
 
-    async def fetch(self, timeout: float = None) -> Union[List[ModelBase], List[Record]]:
+    async def fetch(self, timeout: float|None = None) -> Union[List[ModelBase], List[Record]]:
         """Run query method `fetch` that returns the results in model class objects
 
         Returns the results in model class objects.
@@ -920,7 +938,7 @@ class ModelQuery():
         query, args = self.getq()
         return await self.db.fetch(query, *args, timeout=timeout, model_class=self.model)
 
-    async def fetchrow(self, timeout: float = None) -> Union[ModelBase, Record]:
+    async def fetchrow(self, timeout: float|None = None) -> Union[ModelBase, Record]:
         """Make a query and get the first row.
 
         Resultant record is mapped to model_class object.
@@ -934,7 +952,7 @@ class ModelQuery():
         query, args = self.getq()
         return await self.db.fetchrow(query, *args, timeout=timeout, model_class=self.model)
 
-    async def fetchval(self, column: int = 0, timeout: float = None) -> Any:
+    async def fetchval(self, column: int = 0, timeout: float|None = None) -> Any:
         """Run the query and return a column value in the first row.
 
         Args:
@@ -947,7 +965,7 @@ class ModelQuery():
         query, args = self.getq()
         return await self.db.fetchval(query, *args, column=column, timeout=timeout)
 
-    async def execute(self, timeout: float = None) -> str:
+    async def execute(self, timeout: float|None = None) -> str:
         """Execute the query.
 
         Args:
