@@ -6,9 +6,9 @@ __copyright__ = 'Copyright © Md Jahidul Hamid <https://github.com/neurobin/>'
 __license__ = '[BSD](http://www.opensource.org/licenses/bsd-license.php)'
 __version__ = '0.0.1'
 
-import copy
+import copy, inspect
 from typing import Any, Optional, Callable, Tuple, Dict, List, Union
-from morm.types import Void
+from morm.void import Void
 import morm.exceptions as ex
 
 
@@ -184,6 +184,46 @@ class ColumnConfig():
             raise ex.UnsupportedError(f"{self.conf['sql_engine']} not supported yet.")
 
 
+def is_sql_array(value: Any) -> bool:
+    """Check if the value is a list of sql values.
+
+    Args:
+        value (list): list of values
+
+    Returns:
+        bool: True if the value is a list of sql values
+    """
+    if not isinstance(value, list): return False
+    if len(value) == 0: return True
+    t = type(value[0])
+    for v in value:
+        if type(v) != t:
+            return False
+    return True
+
+
+def sql_val(value: Any, sql_type: str) -> str|int|float|bool|None:
+    """Return the value as a string that can be used in sql.
+
+    Args:
+        value (Any): Any value
+
+    Returns:
+        str: string representation of the value
+    """
+    if isinstance(value, list):
+        return f"ARRAY[{', '.join([str(sql_val(x, sql_type)) for x in value])}]" if value else f'ARRAY[]::{sql_type}'
+    value = str(value)
+    if value.lower() in ['true']: return 'true'
+    if value.lower() in ['false']: return 'false'
+    if value.lower() in ['null','none']: return 'null'
+    try:
+        if '.' in value: return float(value)
+        return int(value)
+    except:
+        return f"'{value}'"
+
+
 class Field(object):
     """Initialize the Field object with data type (sql).
 
@@ -237,14 +277,22 @@ class Field(object):
                 help_text: str = '',
                 validator: Callable=always_valid,
                 modifier: Callable=nomodify,
-                fallback=False,):
+                fallback=False,): # if you add new param here, update __repr__ method
+        # Rules for using a variable name here as local variables go into the self._json_:
+        # 1. Must precede with underscore if not in the parameter list
+        # 2. Make sure to exclude unnecessary variables in the self._json_ like 'self' etc..
+        _init_args = list(locals().keys())[1:] # this must be the first line here in __init__
+
         self.sql_type = sql_type
-        unq_constraint = '__UNQ_{table}_{column}__'
+        _unique_constraint = '__UNQ_{table}_{column}__'
         if unique:
-            ualq = 'ALTER TABLE "{table}" ADD CONSTRAINT "%s" UNIQUE ("{column}");' % (unq_constraint,)
+            _sql_unique = 'ALTER TABLE "{table}" ADD CONSTRAINT "%s" UNIQUE ("{column}");' % (_unique_constraint,)
         else:
-            ualq = 'ALTER TABLE "{table}" DROP CONSTRAINT IF EXISTS "%s";' % (unq_constraint,)
-        sql_alter = (ualq, *sql_alter)
+            _sql_unique = 'ALTER TABLE "{table}" DROP CONSTRAINT IF EXISTS "%s";' % (_unique_constraint,)
+        sql_alter = (_sql_unique, *sql_alter)
+        # handle default
+        if isinstance(default, (int, float, str, bool)) or is_sql_array(default):
+            sql_alter = (*sql_alter, "ALTER TABLE \"{table}\" ALTER COLUMN \"{column}\" SET DEFAULT "+f"{sql_val(default, sql_type)};")
         self.sql_conf = ColumnConfig(sql_type=sql_type, sql_onadd=sql_onadd, sql_ondrop=sql_ondrop, sql_alter=sql_alter, sql_engine=sql_engine)
         self.validator = validator
         self.modifier = modifier
@@ -261,21 +309,46 @@ class Field(object):
         self.choices = choices
         self.help_text = help_text
 
+        # make a json
+        self._json_ = {
+            '_name': self.name,
+            '_init_args': _init_args,
+        }
+        args = locals()
+        for k,v in args.items():
+            if k in ['self', '_init_args']: continue
+            if callable(v):
+                self._json_[k] = inspect.getsource(v)
+            else:
+                self._json_[k] = 'Void' if v == Void else v
+
 
     def __eq__(self, other: 'Field') -> bool: # type: ignore
-        return self.sql_conf == other.sql_conf
+        return bool(other and self.sql_conf == other.sql_conf)
 
     def __repr__(self):
-        reprs = [repr(self.sql_type)]
-        cc = ['sql_onadd','sql_ondrop','sql_alter','sql_engine',]
-        for k in cc:
-            reprs.append(f'{k}={repr(self.sql_conf.conf[k])}')
-        s = ['default','validator','modifier','fallback',]
-        for k in s:
-            reprs.append(f'{k}={repr(self.__dict__[k])}')
+        reprs = []
+        for k in self._json_['_init_args']:
+            if k == 'sql_type': reprs.append(repr(self.sql_type))
+            elif k in ['sql_onadd','sql_ondrop','sql_alter','sql_engine',]:
+                reprs.append(f'{k}={repr(self.sql_conf.conf[k])}')
+            else:
+                try:
+                    if callable(self.__dict__[k]):
+                        reprs.append(f'{k}={inspect.getsource(self.__dict__[k])}')
+                    else:
+                        reprs.append(f'{k}={repr(self.__dict__[k])}')
+                except KeyError: pass
         body = ', '.join(reprs)
         return f'{self.__class__.__name__}({body})'
 
+    def to_json(self):
+        res = self._json_.copy()
+        res['_name'] = self.name
+        res['_repr'] = self.__repr__()
+        del res['_init_args']
+        return res
+
     def __invert__(self):
         return self.name
 
