@@ -4,18 +4,13 @@
 __author__ = 'Md Jahidul Hamid <jahidulhamid@yahoo.com>'
 __copyright__ = 'Copyright © Md Jahidul Hamid <https://github.com/neurobin/>'
 __license__ = '[BSD](http://www.opensource.org/licenses/bsd-license.php)'
-__version__ = '0.0.1'
+__version__ = '0.0.2'
 
 import inspect
-import typing
-from typing import Optional, Dict, List, Tuple, TypeVar, Union, Any, Iterator
-from collections import OrderedDict
+from typing import Dict, List, Tuple, Any, Iterator, ClassVar
 import copy
-from abc import ABCMeta
-from asyncpg import Record # type: ignore
-from morm.exceptions import ItemDoesNotExistError
 from morm.fields.field import Field, FieldValue
-from morm.types import Void
+from morm.void import Void
 import morm.meta as mt      # for internal use
 
 # morm.db must not be imported here.
@@ -37,7 +32,7 @@ class _FieldNames():
 
 
 class ModelType(type):
-    Meta: typing.ClassVar # fixing mypy error: "ModelType" has no attribute "Meta"
+    Meta: ClassVar # fixing mypy error: "ModelType" has no attribute "Meta"
     def __new__(mcs, class_name: str, bases: tuple, attrs: dict):
         # Ensure initialization is only performed for subclasses of Model
         # excluding Model class itself.
@@ -87,8 +82,8 @@ class ModelType(type):
         if meta_attrs['proxy']:
             #proxy model inherits everything
             try:
-                meta_attrs['db_table'] = BaseMeta.db_table
-                meta_attrs['abstract'] = BaseMeta.abstract
+                meta_attrs['db_table'] = BaseMeta.db_table #type: ignore
+                meta_attrs['abstract'] = BaseMeta.abstract #type: ignore
             except AttributeError:
                 raise TypeError(f"This model '{class_name}' can not be a proxy model. It does not have a valid base or super base non-proxy model")
         else:
@@ -129,6 +124,9 @@ class ModelType(type):
             new_attrs['__classcell__'] = classcell
         return super().__new__(mcs, class_name, bases, new_attrs)
 
+    def __repr__(cls):
+        return inspect.getsource(cls)
+
     def __setattr__(self, k, v):
         raise NotImplementedError("You can not set model attributes outside model definition.")
 
@@ -192,6 +190,18 @@ class ModelType(type):
         """
         return self.Meta._field_defs_
 
+    def _get_all_fields_json_(self) -> Dict[str, Dict]:
+        """Get all fields on model without applying any restriction in JSON like dict
+
+        Returns:
+            Dict[str, Dict]: Dictionary of all fields in JSON like dict
+        """
+        res = {}
+        all_fields = self._get_all_fields_()
+        for k,v in all_fields.items():
+            res[k] = v.to_json()
+        return res
+
     def _check_field_name_(self, n: str) -> str:
         """Return the field name if exists else raise AttributeError
 
@@ -230,7 +240,31 @@ class ModelType(type):
                 continue
             yield k
 
-    def _get_FieldValue_data_valid_(self, data: dict, up=False) -> Iterator[Tuple[str, Any]]:
+    def _get_fields_json_(self, up=False) -> Dict[str, Dict]:
+        """Get fields in JSON like dict that pass include/exclude criteria
+
+        Args:
+            up (bool, optional): up criteria or down criteria. Defaults to False (down).
+
+        Returns:
+            Dict[str, Dict]: Dictionary of fields in JSON like dict
+        """
+        res = {}
+        fields = self._get_fields_(up)
+        all_fields = self._get_all_fields_()
+        for k in fields:
+            res[k] = all_fields[k].to_json()
+        return res
+
+    def _run_validations_(self, k: str, v: FieldValue):
+        try:
+            validator = getattr(self, '_clean_' + k)
+            v.value = validator(self, v.value)
+        except AttributeError:
+            v.value = v.value # at least trigger the value validation
+
+
+    def _get_FieldValue_data_valid_(self, data: dict, up=False, validate_all=False) -> Iterator[Tuple[str, Any]]:
         """Yields valid key,value pairs from data.
 
         Validity is checked against include/exclude key/value criteria.
@@ -252,10 +286,13 @@ class ModelType(type):
             exclude_fields = self.Meta.exclude_fields_down
         # new_data = type(data)()
         for k,v in data.items():
+            if validate_all: self._run_validations_(k, v)
             if not self._is_valid_key_(k, fields, exclude_fields):
                 continue
             if not self._is_valid_value_(k, v.value, exclude_values):
                 continue
+            if not validate_all: # run validations for to-be-changed fields only
+                self._run_validations_(k, v)
             yield k, v
 
 
@@ -412,15 +449,19 @@ class ModelBase(metaclass=ModelType):
             raise AttributeError(f"No such field ('{k}') in model '{self.__class__.__name__}''")
         # v = fields[k].clean(v)
         # super().__setattr__(k, v)
-        if self.__class__._is_valid_up_(k, v):
-            if k in self.Meta._fromdb_:
-                fields[k]._ignore_first_change_count_ = True
-                self.Meta._fromdb_.remove(k)
-            fields[k].value = v
-        elif k in self.Meta._fromdb_:
+        if k in self.Meta._fromdb_:
             self.Meta._fromdb_.remove(k)
+            if self.__class__._is_valid_down_(k, v):
+                fields[k].value = v
+            elif self.__class__._is_valid_up_(k, v):
+                fields[k]._ignore_first_change_count_ = True
+                fields[k].value = v
+            else:
+                raise AttributeError(f'Can not set field `{k}`. It is excluded using either exclude_fields_up/down or exclude_values_up/down in {self.__class__.__name__} Meta class. Or you are trying to set an invalid value: {v}')
+        elif self.__class__._is_valid_up_(k, v):
+            fields[k].value = v
         else:
-            raise AttributeError(f'Can not set field `{k}`. It is excluded using either exclude_fields_up or exclude_values_up in {self.__class__.__name__} Meta class. Or you are trying to set an invalid value: {v}')
+            raise AttributeError(f'Can not set field `{k}`. It is excluded using either exclude_fields_up/down or exclude_values_up/down in {self.__class__.__name__} Meta class. Or you are trying to set an invalid value: {v}')
 
     def __repr__(self):
         reprs = []
@@ -523,7 +564,7 @@ class Model(ModelBase):
 
     ```python
     from morm.model import Model
-    from morm.datetime import timestamp
+    from morm.dt import timestamp
 
     class Base(Model):
         class Meta:
